# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TriggerArgs', 'Trigger']

@pulumi.input_type
class TriggerArgs:
    def __init__(__self__, *,
                 container_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nats: Optional[pulumi.Input['TriggerNatsArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs: Optional[pulumi.Input['TriggerSqsArgs']] = None):
        """
        The set of arguments for constructing a Trigger resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container to create a trigger for.
        :param pulumi.Input[_builtins.str] description: The description of the trigger.
        :param pulumi.Input[_builtins.str] name: The unique name of the trigger. If not provided, a random name is generated.
        :param pulumi.Input['TriggerNatsArgs'] nats: The configuration for the Scaleway NATS account used by the trigger
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace is created.
        :param pulumi.Input['TriggerSqsArgs'] sqs: The configuration of the Scaleway SQS queue used by the trigger
        """
        pulumi.set(__self__, "container_id", container_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nats is not None:
            pulumi.set(__self__, "nats", nats)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sqs is not None:
            pulumi.set(__self__, "sqs", sqs)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the container to create a trigger for.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "container_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the trigger.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the trigger. If not provided, a random name is generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def nats(self) -> Optional[pulumi.Input['TriggerNatsArgs']]:
        """
        The configuration for the Scaleway NATS account used by the trigger
        """
        return pulumi.get(self, "nats")

    @nats.setter
    def nats(self, value: Optional[pulumi.Input['TriggerNatsArgs']]):
        pulumi.set(self, "nats", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which the namespace is created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def sqs(self) -> Optional[pulumi.Input['TriggerSqsArgs']]:
        """
        The configuration of the Scaleway SQS queue used by the trigger
        """
        return pulumi.get(self, "sqs")

    @sqs.setter
    def sqs(self, value: Optional[pulumi.Input['TriggerSqsArgs']]):
        pulumi.set(self, "sqs", value)


@pulumi.input_type
class _TriggerState:
    def __init__(__self__, *,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nats: Optional[pulumi.Input['TriggerNatsArgs']] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs: Optional[pulumi.Input['TriggerSqsArgs']] = None):
        """
        Input properties used for looking up and filtering Trigger resources.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container to create a trigger for.
        :param pulumi.Input[_builtins.str] description: The description of the trigger.
        :param pulumi.Input[_builtins.str] name: The unique name of the trigger. If not provided, a random name is generated.
        :param pulumi.Input['TriggerNatsArgs'] nats: The configuration for the Scaleway NATS account used by the trigger
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace is created.
        :param pulumi.Input['TriggerSqsArgs'] sqs: The configuration of the Scaleway SQS queue used by the trigger
        """
        if container_id is not None:
            pulumi.set(__self__, "container_id", container_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nats is not None:
            pulumi.set(__self__, "nats", nats)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sqs is not None:
            pulumi.set(__self__, "sqs", sqs)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the container to create a trigger for.
        """
        return pulumi.get(self, "container_id")

    @container_id.setter
    def container_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "container_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the trigger.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the trigger. If not provided, a random name is generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def nats(self) -> Optional[pulumi.Input['TriggerNatsArgs']]:
        """
        The configuration for the Scaleway NATS account used by the trigger
        """
        return pulumi.get(self, "nats")

    @nats.setter
    def nats(self, value: Optional[pulumi.Input['TriggerNatsArgs']]):
        pulumi.set(self, "nats", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which the namespace is created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def sqs(self) -> Optional[pulumi.Input['TriggerSqsArgs']]:
        """
        The configuration of the Scaleway SQS queue used by the trigger
        """
        return pulumi.get(self, "sqs")

    @sqs.setter
    def sqs(self, value: Optional[pulumi.Input['TriggerSqsArgs']]):
        pulumi.set(self, "sqs", value)


@pulumi.type_token("scaleway:containers/trigger:Trigger")
class Trigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nats: Optional[pulumi.Input[Union['TriggerNatsArgs', 'TriggerNatsArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs: Optional[pulumi.Input[Union['TriggerSqsArgs', 'TriggerSqsArgsDict']]] = None,
                 __props__=None):
        """
        The `containers.Trigger` resource allows you to create and manage triggers for Scaleway [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Containers triggers [documentation](https://www.scaleway.com/en/docs/serverless/containers/how-to/add-trigger-to-a-container/) and [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/#path-triggers-list-all-triggers) for more information.

        ## Example Usage

        ### SQS

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Trigger("main",
            container_id=main_scaleway_container["id"],
            name="my-trigger",
            sqs={
                "project_id": main_scaleway_mnq_sqs["projectId"],
                "queue": "MyQueue",
                "region": main_scaleway_mnq_sqs["region"],
            })
        ```

        ### NATS

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Trigger("main",
            container_id=main_scaleway_container["id"],
            name="my-trigger",
            nats={
                "account_id": main_scaleway_mnq_nats_account["id"],
                "subject": "MySubject",
                "region": main_scaleway_mnq_nats_account["region"],
            })
        ```

        ## Import

        Container Triggers can be imported using `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:containers/trigger:Trigger main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container to create a trigger for.
        :param pulumi.Input[_builtins.str] description: The description of the trigger.
        :param pulumi.Input[_builtins.str] name: The unique name of the trigger. If not provided, a random name is generated.
        :param pulumi.Input[Union['TriggerNatsArgs', 'TriggerNatsArgsDict']] nats: The configuration for the Scaleway NATS account used by the trigger
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace is created.
        :param pulumi.Input[Union['TriggerSqsArgs', 'TriggerSqsArgsDict']] sqs: The configuration of the Scaleway SQS queue used by the trigger
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `containers.Trigger` resource allows you to create and manage triggers for Scaleway [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Containers triggers [documentation](https://www.scaleway.com/en/docs/serverless/containers/how-to/add-trigger-to-a-container/) and [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/#path-triggers-list-all-triggers) for more information.

        ## Example Usage

        ### SQS

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Trigger("main",
            container_id=main_scaleway_container["id"],
            name="my-trigger",
            sqs={
                "project_id": main_scaleway_mnq_sqs["projectId"],
                "queue": "MyQueue",
                "region": main_scaleway_mnq_sqs["region"],
            })
        ```

        ### NATS

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Trigger("main",
            container_id=main_scaleway_container["id"],
            name="my-trigger",
            nats={
                "account_id": main_scaleway_mnq_nats_account["id"],
                "subject": "MySubject",
                "region": main_scaleway_mnq_nats_account["region"],
            })
        ```

        ## Import

        Container Triggers can be imported using `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:containers/trigger:Trigger main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param TriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 container_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nats: Optional[pulumi.Input[Union['TriggerNatsArgs', 'TriggerNatsArgsDict']]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sqs: Optional[pulumi.Input[Union['TriggerSqsArgs', 'TriggerSqsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TriggerArgs.__new__(TriggerArgs)

            if container_id is None and not opts.urn:
                raise TypeError("Missing required property 'container_id'")
            __props__.__dict__["container_id"] = container_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["nats"] = nats
            __props__.__dict__["region"] = region
            __props__.__dict__["sqs"] = sqs
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/containerTrigger:ContainerTrigger")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Trigger, __self__).__init__(
            'scaleway:containers/trigger:Trigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            container_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            nats: Optional[pulumi.Input[Union['TriggerNatsArgs', 'TriggerNatsArgsDict']]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            sqs: Optional[pulumi.Input[Union['TriggerSqsArgs', 'TriggerSqsArgsDict']]] = None) -> 'Trigger':
        """
        Get an existing Trigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] container_id: The unique identifier of the container to create a trigger for.
        :param pulumi.Input[_builtins.str] description: The description of the trigger.
        :param pulumi.Input[_builtins.str] name: The unique name of the trigger. If not provided, a random name is generated.
        :param pulumi.Input[Union['TriggerNatsArgs', 'TriggerNatsArgsDict']] nats: The configuration for the Scaleway NATS account used by the trigger
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace is created.
        :param pulumi.Input[Union['TriggerSqsArgs', 'TriggerSqsArgsDict']] sqs: The configuration of the Scaleway SQS queue used by the trigger
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TriggerState.__new__(_TriggerState)

        __props__.__dict__["container_id"] = container_id
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["nats"] = nats
        __props__.__dict__["region"] = region
        __props__.__dict__["sqs"] = sqs
        return Trigger(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="containerId")
    def container_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the container to create a trigger for.
        """
        return pulumi.get(self, "container_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the trigger.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the trigger. If not provided, a random name is generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def nats(self) -> pulumi.Output[Optional['outputs.TriggerNats']]:
        """
        The configuration for the Scaleway NATS account used by the trigger
        """
        return pulumi.get(self, "nats")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`). The region in which the namespace is created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def sqs(self) -> pulumi.Output[Optional['outputs.TriggerSqs']]:
        """
        The configuration of the Scaleway SQS queue used by the trigger
        """
        return pulumi.get(self, "sqs")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEventEventResult',
    'GetEventEventResourceResult',
]

@pulumi.output_type
class GetEventEventResult(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 locality: _builtins.str,
                 method_name: _builtins.str,
                 organization_id: _builtins.str,
                 principal_id: _builtins.str,
                 product_name: _builtins.str,
                 project_id: _builtins.str,
                 recorded_at: _builtins.str,
                 request_body: _builtins.str,
                 request_id: _builtins.str,
                 resources: Sequence['outputs.GetEventEventResourceResult'],
                 service_name: _builtins.str,
                 source_ip: _builtins.str,
                 status_code: _builtins.int,
                 user_agent: _builtins.str):
        """
        :param _builtins.str id: ID of the resource attached to the event. (UUID format)
        :param _builtins.str locality: Locality of the resource attached to the event.
        :param _builtins.str method_name: Name of the method of the API call performed.
        :param _builtins.str organization_id: `organization_id`) ID of the Organization containing the Audit Trail events.
        :param _builtins.str principal_id: ID of the User or IAM application at the origin of the event.
        :param _builtins.str product_name: Name of the Scaleway product in a hyphenated format.
        :param _builtins.str project_id: ID of the Project containing the Audit Trail events.
        :param _builtins.str recorded_at: Timestamp of the event. (RFC 3339 format)
        :param _builtins.str request_body: Request at the origin of the event.
        :param _builtins.str request_id: Unique identifier of the request at the origin of the event. (UUID format)
        :param Sequence['GetEventEventResourceArgs'] resources: List of resources attached to the event.
        :param _builtins.str service_name: Name of the service of the API call performed.
        :param _builtins.str source_ip: IP address at the origin of the event.
        :param _builtins.int status_code: HTTP status code resulting of the API call.
        :param _builtins.str user_agent: User Agent at the origin of the event.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "locality", locality)
        pulumi.set(__self__, "method_name", method_name)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "recorded_at", recorded_at)
        pulumi.set(__self__, "request_body", request_body)
        pulumi.set(__self__, "request_id", request_id)
        pulumi.set(__self__, "resources", resources)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "source_ip", source_ip)
        pulumi.set(__self__, "status_code", status_code)
        pulumi.set(__self__, "user_agent", user_agent)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the resource attached to the event. (UUID format)
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def locality(self) -> _builtins.str:
        """
        Locality of the resource attached to the event.
        """
        return pulumi.get(self, "locality")

    @_builtins.property
    @pulumi.getter(name="methodName")
    def method_name(self) -> _builtins.str:
        """
        Name of the method of the API call performed.
        """
        return pulumi.get(self, "method_name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        `organization_id`) ID of the Organization containing the Audit Trail events.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> _builtins.str:
        """
        ID of the User or IAM application at the origin of the event.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="productName")
    def product_name(self) -> _builtins.str:
        """
        Name of the Scaleway product in a hyphenated format.
        """
        return pulumi.get(self, "product_name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        ID of the Project containing the Audit Trail events.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="recordedAt")
    def recorded_at(self) -> _builtins.str:
        """
        Timestamp of the event. (RFC 3339 format)
        """
        return pulumi.get(self, "recorded_at")

    @_builtins.property
    @pulumi.getter(name="requestBody")
    def request_body(self) -> _builtins.str:
        """
        Request at the origin of the event.
        """
        return pulumi.get(self, "request_body")

    @_builtins.property
    @pulumi.getter(name="requestId")
    def request_id(self) -> _builtins.str:
        """
        Unique identifier of the request at the origin of the event. (UUID format)
        """
        return pulumi.get(self, "request_id")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetEventEventResourceResult']:
        """
        List of resources attached to the event.
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        Name of the service of the API call performed.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> _builtins.str:
        """
        IP address at the origin of the event.
        """
        return pulumi.get(self, "source_ip")

    @_builtins.property
    @pulumi.getter(name="statusCode")
    def status_code(self) -> _builtins.int:
        """
        HTTP status code resulting of the API call.
        """
        return pulumi.get(self, "status_code")

    @_builtins.property
    @pulumi.getter(name="userAgent")
    def user_agent(self) -> _builtins.str:
        """
        User Agent at the origin of the event.
        """
        return pulumi.get(self, "user_agent")


@pulumi.output_type
class GetEventEventResourceResult(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 name: _builtins.str,
                 type: _builtins.str):
        """
        :param _builtins.str id: ID of the resource attached to the event. (UUID format)
        :param _builtins.str name: Name of the Scaleway resource.
        :param _builtins.str type: Type of the Scaleway resource.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the resource attached to the event. (UUID format)
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Scaleway resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of the Scaleway resource.
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAclResult',
    'AwaitableGetAclResult',
    'get_acl',
    'get_acl_output',
]

@pulumi.output_type
class GetAclResult:
    """
    A collection of values returned by getAcl.
    """
    def __init__(__self__, default_policy=None, id=None, is_ipv6=None, region=None, rules=None, vpc_id=None):
        if default_policy and not isinstance(default_policy, str):
            raise TypeError("Expected argument 'default_policy' to be a str")
        pulumi.set(__self__, "default_policy", default_policy)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_ipv6 and not isinstance(is_ipv6, bool):
            raise TypeError("Expected argument 'is_ipv6' to be a bool")
        pulumi.set(__self__, "is_ipv6", is_ipv6)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="defaultPolicy")
    def default_policy(self) -> _builtins.str:
        return pulumi.get(self, "default_policy")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "is_ipv6")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetAclRuleResult']:
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> _builtins.str:
        return pulumi.get(self, "vpc_id")


class AwaitableGetAclResult(GetAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAclResult(
            default_policy=self.default_policy,
            id=self.id,
            is_ipv6=self.is_ipv6,
            region=self.region,
            rules=self.rules,
            vpc_id=self.vpc_id)


def get_acl(is_ipv6: Optional[_builtins.bool] = None,
            region: Optional[_builtins.str] = None,
            vpc_id: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAclResult:
    """
    Gets information about a VPC ACL (Access Control List).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the IPv4 ACL for a VPC
    my_acl = scaleway.network.get_acl(vpc_id=my_vpc["id"],
        is_ipv6=False)
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the IPv6 ACL for a VPC
    my_acl_v6 = scaleway.network.get_acl(vpc_id=my_vpc["id"],
        is_ipv6=True)
    ```


    :param _builtins.bool is_ipv6: Whether to get the IPv6 ACL.
    :param _builtins.str region: `region`). The region in which the ACL exists.
    :param _builtins.str vpc_id: The VPC ID to look up the ACL for.
    """
    __args__ = dict()
    __args__['isIpv6'] = is_ipv6
    __args__['region'] = region
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:network/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult).value

    return AwaitableGetAclResult(
        default_policy=pulumi.get(__ret__, 'default_policy'),
        id=pulumi.get(__ret__, 'id'),
        is_ipv6=pulumi.get(__ret__, 'is_ipv6'),
        region=pulumi.get(__ret__, 'region'),
        rules=pulumi.get(__ret__, 'rules'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_acl_output(is_ipv6: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                   region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   vpc_id: Optional[pulumi.Input[_builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAclResult]:
    """
    Gets information about a VPC ACL (Access Control List).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the IPv4 ACL for a VPC
    my_acl = scaleway.network.get_acl(vpc_id=my_vpc["id"],
        is_ipv6=False)
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the IPv6 ACL for a VPC
    my_acl_v6 = scaleway.network.get_acl(vpc_id=my_vpc["id"],
        is_ipv6=True)
    ```


    :param _builtins.bool is_ipv6: Whether to get the IPv6 ACL.
    :param _builtins.str region: `region`). The region in which the ACL exists.
    :param _builtins.str vpc_id: The VPC ID to look up the ACL for.
    """
    __args__ = dict()
    __args__['isIpv6'] = is_ipv6
    __args__['region'] = region
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:network/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult)
    return __ret__.apply(lambda __response__: GetAclResult(
        default_policy=pulumi.get(__response__, 'default_policy'),
        id=pulumi.get(__response__, 'id'),
        is_ipv6=pulumi.get(__response__, 'is_ipv6'),
        region=pulumi.get(__response__, 'region'),
        rules=pulumi.get(__response__, 'rules'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 gateway_type: pulumi.Input[_builtins.str],
                 private_network_id: pulumi.Input[_builtins.str],
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        pulumi.set(__self__, "gateway_type", gateway_type)
        pulumi.set(__self__, "private_network_id", private_network_id)
        if ipam_private_ipv4_id is not None:
            pulumi.set(__self__, "ipam_private_ipv4_id", ipam_private_ipv4_id)
        if ipam_private_ipv6_id is not None:
            pulumi.set(__self__, "ipam_private_ipv6_id", ipam_private_ipv6_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_configs is not None:
            pulumi.set(__self__, "public_configs", public_configs)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> pulumi.Input[_builtins.str]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @gateway_type.setter
    def gateway_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "gateway_type", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @ipam_private_ipv4_id.setter
    def ipam_private_ipv4_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv4_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @ipam_private_ipv6_id.setter
    def ipam_private_ipv6_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv6_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @public_configs.setter
    def public_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]):
        pulumi.set(self, "public_configs", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the VPN gateway (typically 12876 for Scaleway).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the VPN gateway is associated with.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[_builtins.str] status: The status of the VPN gateway.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if gateway_type is not None:
            pulumi.set(__self__, "gateway_type", gateway_type)
        if ipam_private_ipv4_id is not None:
            pulumi.set(__self__, "ipam_private_ipv4_id", ipam_private_ipv4_id)
        if ipam_private_ipv6_id is not None:
            pulumi.set(__self__, "ipam_private_ipv6_id", ipam_private_ipv6_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public_configs is not None:
            pulumi.set(__self__, "public_configs", public_configs)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The AS Number of the VPN gateway (typically 12876 for Scaleway).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @gateway_type.setter
    def gateway_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "gateway_type", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @ipam_private_ipv4_id.setter
    def ipam_private_ipv4_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv4_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @ipam_private_ipv6_id.setter
    def ipam_private_ipv6_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_private_ipv6_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the VPN gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @public_configs.setter
    def public_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayPublicConfigArgs']]]]):
        pulumi.set(self, "public_configs", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the VPN gateway.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:s2svpn/gateway:Gateway")
class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Site-to-Site VPN Gateways.
        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        ```

        ## Import

        VPN Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/gateway:Gateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Site-to-Site VPN Gateways.
        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc = scaleway.network.Vpc("vpc", name="my-vpc")
        pn = scaleway.network.PrivateNetwork("pn",
            name="my-private-network",
            vpc_id=vpc.id,
            ipv4_subnet={
                "subnet": "10.0.1.0/24",
            })
        gateway = scaleway.s2svpn.Gateway("gateway",
            name="my-vpn-gateway",
            gateway_type="VGW-S",
            private_network_id=pn.id)
        ```

        ## Import

        VPN Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/gateway:Gateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            if gateway_type is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_type'")
            __props__.__dict__["gateway_type"] = gateway_type
            __props__.__dict__["ipam_private_ipv4_id"] = ipam_private_ipv4_id
            __props__.__dict__["ipam_private_ipv6_id"] = ipam_private_ipv6_id
            __props__.__dict__["name"] = name
            if private_network_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_network_id'")
            __props__.__dict__["private_network_id"] = private_network_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["public_configs"] = public_configs
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["zone"] = zone
            __props__.__dict__["asn"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(Gateway, __self__).__init__(
            'scaleway:s2svpn/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[_builtins.int]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            gateway_type: Optional[pulumi.Input[_builtins.str]] = None,
            ipam_private_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
            ipam_private_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the VPN gateway (typically 12876 for Scaleway).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] gateway_type: The VPN gateway type (commercial offer type).
        :param pulumi.Input[_builtins.str] ipam_private_ipv4_id: The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_private_ipv6_id: The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] name: The name of the VPN gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the VPN gateway is associated with.
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network to attach to the VPN gateway.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the VPN gateway is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayPublicConfigArgs', 'GatewayPublicConfigArgsDict']]]] public_configs: The public endpoint configuration of the VPN gateway. See Public Config below.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the VPN gateway should be created.
        :param pulumi.Input[_builtins.str] status: The status of the VPN gateway.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the VPN gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the VPN gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the VPN gateway should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["gateway_type"] = gateway_type
        __props__.__dict__["ipam_private_ipv4_id"] = ipam_private_ipv4_id
        __props__.__dict__["ipam_private_ipv6_id"] = ipam_private_ipv6_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public_configs"] = public_configs
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["zone"] = zone
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Output[_builtins.int]:
        """
        The AS Number of the VPN gateway (typically 12876 for Scaleway).
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="gatewayType")
    def gateway_type(self) -> pulumi.Output[_builtins.str]:
        """
        The VPN gateway type (commercial offer type).
        """
        return pulumi.get(self, "gateway_type")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv4Id")
    def ipam_private_ipv4_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the IPAM private IPv4 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv4_id")

    @_builtins.property
    @pulumi.getter(name="ipamPrivateIpv6Id")
    def ipam_private_ipv6_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the IPAM private IPv6 address to attach to the VPN gateway.
        """
        return pulumi.get(self, "ipam_private_ipv6_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the VPN gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the VPN gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Private Network to attach to the VPN gateway.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the VPN gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicConfigs")
    def public_configs(self) -> pulumi.Output[Sequence['outputs.GatewayPublicConfig']]:
        """
        The public endpoint configuration of the VPN gateway. See Public Config below.
        """
        return pulumi.get(self, "public_configs")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the VPN gateway should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the VPN gateway.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of tags to apply to the VPN gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the VPN gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the VPN gateway should be created.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PrivateNetworkArgs', 'PrivateNetwork']

@pulumi.input_type
class PrivateNetworkArgs:
    def __init__(__self__, *,
                 lb_id: pulumi.Input[_builtins.str],
                 private_network_id: pulumi.Input[_builtins.str],
                 ipam_ip_ids: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PrivateNetwork resource.
        :param pulumi.Input[_builtins.str] lb_id: The load-balancer ID to attach the private network to.
        :param pulumi.Input[_builtins.str] private_network_id: The private network ID to attach.
        :param pulumi.Input[_builtins.str] ipam_ip_ids: The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Private Network attachment is associated with.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Private Network should be attached.
        """
        pulumi.set(__self__, "lb_id", lb_id)
        pulumi.set(__self__, "private_network_id", private_network_id)
        if ipam_ip_ids is not None:
            pulumi.set(__self__, "ipam_ip_ids", ipam_ip_ids)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="lbId")
    def lb_id(self) -> pulumi.Input[_builtins.str]:
        """
        The load-balancer ID to attach the private network to.
        """
        return pulumi.get(self, "lb_id")

    @lb_id.setter
    def lb_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "lb_id", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Input[_builtins.str]:
        """
        The private network ID to attach.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @ipam_ip_ids.setter
    def ipam_ip_ids(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Private Network attachment is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Private Network should be attached.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _PrivateNetworkState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[_builtins.str]] = None,
                 lb_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PrivateNetwork resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the Private Network attachment (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipam_ip_ids: The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        :param pulumi.Input[_builtins.str] lb_id: The load-balancer ID to attach the private network to.
        :param pulumi.Input[_builtins.str] private_network_id: The private network ID to attach.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Private Network attachment is associated with.
        :param pulumi.Input[_builtins.str] status: The status of the Private Network attachment.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the Private Network attachment (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Private Network should be attached.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if ipam_ip_ids is not None:
            pulumi.set(__self__, "ipam_ip_ids", ipam_ip_ids)
        if lb_id is not None:
            pulumi.set(__self__, "lb_id", lb_id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the Private Network attachment (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @ipam_ip_ids.setter
    def ipam_ip_ids(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="lbId")
    def lb_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The load-balancer ID to attach the private network to.
        """
        return pulumi.get(self, "lb_id")

    @lb_id.setter
    def lb_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lb_id", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private network ID to attach.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Private Network attachment is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the Private Network attachment.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the Private Network attachment (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Private Network should be attached.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:loadbalancers/privateNetwork:PrivateNetwork")
class PrivateNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ipam_ip_ids: Optional[pulumi.Input[_builtins.str]] = None,
                 lb_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Load Balancer Private Network attachments.

        For more information, see the [main documentation](https://www.scaleway.com/en/docs/load-balancer/how-to/use-with-private-network/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc01 = scaleway.network.Vpc("vpc01", name="my vpc")
        pn01 = scaleway.network.PrivateNetwork("pn01",
            vpc_id=vpc01.id,
            ipv4_subnet={
                "subnet": "172.16.32.0/22",
            })
        ip01 = scaleway.ipam.Ip("ip01",
            address="172.16.32.7",
            sources=[{
                "private_network_id": pn01.id,
            }])
        lb01 = scaleway.loadbalancers.LoadBalancer("lb01",
            name="test-lb-private-network",
            type="LB-S")
        lbpn01 = scaleway.loadbalancers.PrivateNetwork("lbpn01",
            lb_id=lb01.id,
            private_network_id=pn01.id,
            ipam_ip_ids=ip01.id)
        ```

        ## Import

        Private Network attachments can be imported using `{zone}/{lb-id}/{private-network-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:loadbalancers/privateNetwork:PrivateNetwork lbpn01 fr-par-1/11111111-1111-1111-1111-111111111111/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] ipam_ip_ids: The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        :param pulumi.Input[_builtins.str] lb_id: The load-balancer ID to attach the private network to.
        :param pulumi.Input[_builtins.str] private_network_id: The private network ID to attach.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Private Network attachment is associated with.
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Private Network should be attached.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrivateNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Load Balancer Private Network attachments.

        For more information, see the [main documentation](https://www.scaleway.com/en/docs/load-balancer/how-to/use-with-private-network/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpc01 = scaleway.network.Vpc("vpc01", name="my vpc")
        pn01 = scaleway.network.PrivateNetwork("pn01",
            vpc_id=vpc01.id,
            ipv4_subnet={
                "subnet": "172.16.32.0/22",
            })
        ip01 = scaleway.ipam.Ip("ip01",
            address="172.16.32.7",
            sources=[{
                "private_network_id": pn01.id,
            }])
        lb01 = scaleway.loadbalancers.LoadBalancer("lb01",
            name="test-lb-private-network",
            type="LB-S")
        lbpn01 = scaleway.loadbalancers.PrivateNetwork("lbpn01",
            lb_id=lb01.id,
            private_network_id=pn01.id,
            ipam_ip_ids=ip01.id)
        ```

        ## Import

        Private Network attachments can be imported using `{zone}/{lb-id}/{private-network-id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:loadbalancers/privateNetwork:PrivateNetwork lbpn01 fr-par-1/11111111-1111-1111-1111-111111111111/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param PrivateNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrivateNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ipam_ip_ids: Optional[pulumi.Input[_builtins.str]] = None,
                 lb_id: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrivateNetworkArgs.__new__(PrivateNetworkArgs)

            __props__.__dict__["ipam_ip_ids"] = ipam_ip_ids
            if lb_id is None and not opts.urn:
                raise TypeError("Missing required property 'lb_id'")
            __props__.__dict__["lb_id"] = lb_id
            if private_network_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_network_id'")
            __props__.__dict__["private_network_id"] = private_network_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["zone"] = zone
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(PrivateNetwork, __self__).__init__(
            'scaleway:loadbalancers/privateNetwork:PrivateNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            ipam_ip_ids: Optional[pulumi.Input[_builtins.str]] = None,
            lb_id: Optional[pulumi.Input[_builtins.str]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'PrivateNetwork':
        """
        Get an existing PrivateNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the Private Network attachment (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipam_ip_ids: The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        :param pulumi.Input[_builtins.str] lb_id: The load-balancer ID to attach the private network to.
        :param pulumi.Input[_builtins.str] private_network_id: The private network ID to attach.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Private Network attachment is associated with.
        :param pulumi.Input[_builtins.str] status: The status of the Private Network attachment.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the Private Network attachment (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Private Network should be attached.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrivateNetworkState.__new__(_PrivateNetworkState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["ipam_ip_ids"] = ipam_ip_ids
        __props__.__dict__["lb_id"] = lb_id
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["zone"] = zone
        return PrivateNetwork(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the Private Network attachment (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> pulumi.Output[_builtins.str]:
        """
        The IPAM ID of a pre-reserved IP address to assign to the Load Balancer on this Private Network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @_builtins.property
    @pulumi.getter(name="lbId")
    def lb_id(self) -> pulumi.Output[_builtins.str]:
        """
        The load-balancer ID to attach the private network to.
        """
        return pulumi.get(self, "lb_id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[_builtins.str]:
        """
        The private network ID to attach.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the Project the Private Network attachment is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the Private Network attachment.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the Private Network attachment (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the Private Network should be attached.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRoutingPolicyResult',
    'AwaitableGetRoutingPolicyResult',
    'get_routing_policy',
    'get_routing_policy_output',
]

@pulumi.output_type
class GetRoutingPolicyResult:
    """
    A collection of values returned by getRoutingPolicy.
    """
    def __init__(__self__, created_at=None, id=None, is_ipv6=None, name=None, organization_id=None, prefix_filter_ins=None, prefix_filter_outs=None, project_id=None, region=None, routing_policy_id=None, tags=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_ipv6 and not isinstance(is_ipv6, bool):
            raise TypeError("Expected argument 'is_ipv6' to be a bool")
        pulumi.set(__self__, "is_ipv6", is_ipv6)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if prefix_filter_ins and not isinstance(prefix_filter_ins, list):
            raise TypeError("Expected argument 'prefix_filter_ins' to be a list")
        pulumi.set(__self__, "prefix_filter_ins", prefix_filter_ins)
        if prefix_filter_outs and not isinstance(prefix_filter_outs, list):
            raise TypeError("Expected argument 'prefix_filter_outs' to be a list")
        pulumi.set(__self__, "prefix_filter_outs", prefix_filter_outs)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if routing_policy_id and not isinstance(routing_policy_id, str):
            raise TypeError("Expected argument 'routing_policy_id' to be a str")
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time of creation of the routing policy.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isIpv6")
    def is_ipv6(self) -> _builtins.bool:
        """
        Whether the routing policy is for IPv6 prefixes.
        """
        return pulumi.get(self, "is_ipv6")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The Organization ID the routing policy is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="prefixFilterIns")
    def prefix_filter_ins(self) -> Sequence[_builtins.str]:
        """
        List of IP prefixes accepted from the peer gateway.
        """
        return pulumi.get(self, "prefix_filter_ins")

    @_builtins.property
    @pulumi.getter(name="prefixFilterOuts")
    def prefix_filter_outs(self) -> Sequence[_builtins.str]:
        """
        List of IP prefixes advertised to the peer gateway.
        """
        return pulumi.get(self, "prefix_filter_outs")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "routing_policy_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        The tags associated with the routing policy.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time of the last update of the routing policy.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetRoutingPolicyResult(GetRoutingPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoutingPolicyResult(
            created_at=self.created_at,
            id=self.id,
            is_ipv6=self.is_ipv6,
            name=self.name,
            organization_id=self.organization_id,
            prefix_filter_ins=self.prefix_filter_ins,
            prefix_filter_outs=self.prefix_filter_outs,
            project_id=self.project_id,
            region=self.region,
            routing_policy_id=self.routing_policy_id,
            tags=self.tags,
            updated_at=self.updated_at)


def get_routing_policy(name: Optional[_builtins.str] = None,
                       project_id: Optional[_builtins.str] = None,
                       region: Optional[_builtins.str] = None,
                       routing_policy_id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoutingPolicyResult:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by routing policy ID
    my_policy = scaleway.s2svpn.get_routing_policy(routing_policy_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_policy = scaleway.s2svpn.get_routing_policy(name="foobar")
    ```


    :param _builtins.str name: The name of the routing policy.
    :param _builtins.str project_id: The ID of the project the routing policy is associated with.
    :param _builtins.str region: `region`) The region in which the routing policy exists.
    :param _builtins.str routing_policy_id: The routing policy ID.
           
           > **Note** You must specify at least one: `name` and/or `routing_policy_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['routingPolicyId'] = routing_policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:s2svpn/getRoutingPolicy:getRoutingPolicy', __args__, opts=opts, typ=GetRoutingPolicyResult).value

    return AwaitableGetRoutingPolicyResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        is_ipv6=pulumi.get(__ret__, 'is_ipv6'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        prefix_filter_ins=pulumi.get(__ret__, 'prefix_filter_ins'),
        prefix_filter_outs=pulumi.get(__ret__, 'prefix_filter_outs'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        routing_policy_id=pulumi.get(__ret__, 'routing_policy_id'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_routing_policy_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              routing_policy_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRoutingPolicyResult]:
    """
    For further information refer to the Site-to-Site VPN [API documentation](https://www.scaleway.com/en/developers/api/site-to-site-vpn/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by routing policy ID
    my_policy = scaleway.s2svpn.get_routing_policy(routing_policy_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    my_policy = scaleway.s2svpn.get_routing_policy(name="foobar")
    ```


    :param _builtins.str name: The name of the routing policy.
    :param _builtins.str project_id: The ID of the project the routing policy is associated with.
    :param _builtins.str region: `region`) The region in which the routing policy exists.
    :param _builtins.str routing_policy_id: The routing policy ID.
           
           > **Note** You must specify at least one: `name` and/or `routing_policy_id`.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['routingPolicyId'] = routing_policy_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:s2svpn/getRoutingPolicy:getRoutingPolicy', __args__, opts=opts, typ=GetRoutingPolicyResult)
    return __ret__.apply(lambda __response__: GetRoutingPolicyResult(
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        is_ipv6=pulumi.get(__response__, 'is_ipv6'),
        name=pulumi.get(__response__, 'name'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        prefix_filter_ins=pulumi.get(__response__, 'prefix_filter_ins'),
        prefix_filter_outs=pulumi.get(__response__, 'prefix_filter_outs'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        routing_policy_id=pulumi.get(__response__, 'routing_policy_id'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'TriggerNats',
    'TriggerSqs',
]

@pulumi.output_type
class TriggerNats(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accountId":
            suggest = "account_id"
        elif key == "projectId":
            suggest = "project_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TriggerNats. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TriggerNats.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TriggerNats.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 subject: _builtins.str,
                 account_id: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 region: Optional[_builtins.str] = None):
        """
        :param _builtins.str subject: The subject to listen to.
        :param _builtins.str account_id: unique identifier of the Messaging and Queuing NATS account.
        :param _builtins.str project_id: THe ID of the project that contains the Messaging and Queuing NATS account (defaults to provider `project_id`)
        :param _builtins.str region: Region where the Messaging and Queuing NATS account is enabled (defaults to provider `region`)
        """
        pulumi.set(__self__, "subject", subject)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def subject(self) -> _builtins.str:
        """
        The subject to listen to.
        """
        return pulumi.get(self, "subject")

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[_builtins.str]:
        """
        unique identifier of the Messaging and Queuing NATS account.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        THe ID of the project that contains the Messaging and Queuing NATS account (defaults to provider `project_id`)
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        Region where the Messaging and Queuing NATS account is enabled (defaults to provider `region`)
        """
        return pulumi.get(self, "region")


@pulumi.output_type
class TriggerSqs(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "namespaceId":
            suggest = "namespace_id"
        elif key == "projectId":
            suggest = "project_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in TriggerSqs. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        TriggerSqs.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        TriggerSqs.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 queue: _builtins.str,
                 namespace_id: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 region: Optional[_builtins.str] = None):
        """
        :param _builtins.str queue: The name of the SQS queue.
        :param _builtins.str namespace_id: ID of the Messaging and Queuing namespace. This argument is deprecated.
        :param _builtins.str project_id: The ID of the project in which SQS is enabled, (defaults to provider `project_id`)
        :param _builtins.str region: Region where SQS is enabled (defaults to provider `region`)
        """
        pulumi.set(__self__, "queue", queue)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def queue(self) -> _builtins.str:
        """
        The name of the SQS queue.
        """
        return pulumi.get(self, "queue")

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    @_utilities.deprecated("""The 'namespace_id' field is deprecated and will be removed in the next major version. It is no longer necessary to specify it""")
    def namespace_id(self) -> Optional[_builtins.str]:
        """
        ID of the Messaging and Queuing namespace. This argument is deprecated.
        """
        return pulumi.get(self, "namespace_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        The ID of the project in which SQS is enabled, (defaults to provider `project_id`)
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        Region where SQS is enabled (defaults to provider `region`)
        """
        return pulumi.get(self, "region")


